@@ -1,7 +1,6 @@
 ##++
-##     CGI Lite v2.04
-##     Last modified: 13 Jun 2014 (see CHANGES)
-##     $Id: Lite.pm,v 1.6 2014/07/04 11:15:04 pete Exp $
+##     CGI Lite v2.05
+##     Last modified: 23 Oct 2014 (see CHANGES)
 ##
 ##     Copyright (c) 1995, 1996, 1997 by Shishir Gundavaram
 ##     All Rights Reserved
@@ -9,6 +8,8 @@
 ##     Permission  to  use,  copy, and distribute is hereby granted,
 ##     providing that the above copyright notice and this permission
 ##     appear in all copies and in supporting documentation.
+##
+##     Changes in versions 2.03 and newer copyright (c) 2014 Pete Houston 
 ##--
 
 ###############################################################################
@@ -44,7 +45,7 @@ CGI::Lite - Process and decode WWW forms and cookies
     $size = $cgi->set_buffer_size ($some_buffer_size);
 
     $status = $cgi->set_directory ('/some/dir');
-    $cgi->set_directory ('/some/dir') || die "Directory doesn't exist.\n";
+    $cgi->set_directory ('/some/dir') or die "Directory doesn't exist.\n";
 
     $cgi->close_all_files;
 
@@ -141,7 +142,7 @@ the CGI object is reused for multiple requests. e.g.
 	while (FCGI::accept > 0)
 	{
 		$Query = $CGI->parse_new_form_data();
-		<process query>
+		# process query
 	}
 
 =item B<parse_cookies>
@@ -347,7 +348,7 @@ Sometimes, it is convenient to have scalar variables that represent
 the various keys in a hash. You can use this method to do just that.
 Say you have a hash like the following:
 
-    %form = ('name'   => 'shishir gundavaram',
+    %form = ('name'   => 'alan wells',
 	     'sport'  => 'track and field',
 	     'events' => '100m');
 
@@ -427,7 +428,7 @@ introduced into the language since 1996.
 With this in mind, there will be two maintained branches of this module
 going forwards. The 2.x branch will retain the backwards compatibility
 but will not have any new features introduced. Changes to this branch
-will be bug fixes only. The new 3.x branch (unwritten as of July 2014)
+will be bug fixes only. The new 3.x branch (unreleased as of October 2014)
 will be the main release and will require a more modern perl (version
 still to be determined but 5.6.0 would be the bare minumum). That 3.x
 branch will have new features and will remove some of the legacy code
@@ -448,6 +449,10 @@ L<CGI::Lite::Request> uses similar method names to CGI.pm thus allowing
 easy transition between them. It uses this module as a
 dependency.
 
+=head1 REPOSITORY
+
+L<https://github.com/openstrike/perl-CGI-Lite/tree/legacy-master>
+
 =head1 MAINTAINER
 
 Maintenance of this module as of May 2014 has been taken over by Pete Houston
@@ -495,6 +500,11 @@ Smylers, Andreas, Ben and Shishir.
 
      Changes in versions 2.03 - present copyright 2014 by Pete Houston
 
+=head1 LICENCE
+
+This program is free software; you can redistribute it and/or modify it
+under the same terms as Perl itself.
+
 =cut
 
 ###############################################################################
@@ -514,7 +524,7 @@ require Exporter;
 ## Global Variables
 ##--
 
-$CGI::Lite::VERSION = '2.04';
+$CGI::Lite::VERSION = '2.05';
 
 ##++
 ##  Start
@@ -603,10 +613,10 @@ sub set_platform
 {
     my ($self, $platform) = @_;
 
-    if ($platform =~ /(?:PC|NT|Windows(?:95)?|DOS)/i) {
+    if ($platform =~ /^(?:PC|NT|Windows(?:95)?|DOS)/i) {
         $self->{platform} = 'PC';
 
-    } elsif ($platform =~ /Mac(?:intosh)?/i) {
+    } elsif ($platform =~ /^Mac(?:intosh)?/i) {
 
 	## Should I check for NeXT here :-)
 
@@ -1018,7 +1028,7 @@ sub _parse_multipart_data
     $code = <<'End_of_Multipart';
 
     my ($seen, $buffer_size, $byte_count, $platform, $eol, $handle, 
-	$directory, $bytes_left, $new_data, $old_data, 
+	$directory, $bytes_left, $new_data, $old_data, $this_boundary,
 	$current_buffer, $changed, $store, $disposition, $headers, 
         $mime_type, $convert, $field, $file, $new_name, $full_path);
 
@@ -1067,14 +1077,14 @@ sub _parse_multipart_data
 	##--
 
 	if ($current_buffer =~ 
-            /(.*?)(?:\015?\012)?-*$boundary-*[\015\012]*(?=(.*))/os) {
+            /(.*?)((?:\015?\012)?-*$boundary-*[\015\012]*)(?=(.*))/os) {
 
-	    ($store, $old_data) = ($1, $2);
+	    ($store, $this_boundary, $old_data) = ($1, $2, $3);
 
             if ($current_buffer =~ 
              /[Cc]ontent-[Dd]isposition: ([^\015\012]+)\015?\012  # Disposition
-              (?:([A-Za-z].*?)(?:\015?\012){2})?                  # Headers
-              (?:\015?\012)?                                      # End
+              (?:([A-Za-z].*?)(?:\015?\012))?                     # Headers
+              (?:\015?\012)                                       # End
               (?=(.*))                                            # Other Data
              /xs) {
 
@@ -1124,7 +1134,9 @@ sub _parse_multipart_data
 
                     $files->{$new_name} = $full_path;
                 } 
-            }
+            } elsif ($byte_count < $total_bytes) {
+				$old_data = $this_boundary . $old_data;
+			}
 
 	} elsif ($old_data) {
             $store    = $old_data;
@@ -1157,23 +1169,26 @@ sub _store
 	$info, $seen) = @_;
 
     if ($file) {
-	if ($convert) {
-	    $$info =~ s/\015\012/$eol/og  if ($platform ne 'PC');
-	    $$info =~ s/\015/$eol/og      if ($platform ne 'Mac');
-	    $$info =~ s/\012/$eol/og      if ($platform ne 'Unix');
-	} else {
+		if ($convert) {
+			if ($platform eq 'PC') {
+				$$info =~ s/\015(?=[^\012])|(?<=[^\015])\012/$eol/og;
+			} else {
+	    		$$info =~ s/\015\012/$eol/og;
+				$$info =~ s/\015/$eol/og      if ($platform ne 'Mac');
+				$$info =~ s/\012/$eol/og      if ($platform ne 'Unix');
+			}
+		}
+
 		binmode $handle;
+		print $handle $$info;
+
+	} elsif ($field) {
+		if ($seen->{$field} > 1) {
+			$self->{web_data}->{$field}->[$seen->{$field}-1] .= $$info;
+		} else {
+			$self->{web_data}->{$field} .= $$info;
+		}
 	}
-
-    	print $handle $$info;
-
-    } elsif ($field) {
-	if ($seen->{$field} > 1) {
-	    $self->{web_data}->{$field}->[$seen->{$field}-1] .= $$info;
-	} else {
-	    $self->{web_data}->{$field} .= $$info;
-        }
-    }
 }
 
 sub _get_file_name
